DeflateEncoder

Struct DeflateEncoder 

pub struct DeflateEncoder<S> { /* private fields */ }
👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Available on crate features stream and deflate only.
A deflate encoder, or compressor.

This structure implements a Stream interface and will read uncompressed data from an underlying stream and emit a stream of compressed data.

Implementations

Source

impl<S: Stream<Item = Result<Bytes>>> DeflateEncoder<S>

pub fn new(inner: S) -> Self

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.

pub fn with_quality(inner: S, level: Level) -> Self

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.

pub fn get_ref(&self) -> &S

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Acquires a reference to the underlying stream that this encoder is wrapping.

pub fn get_mut(&mut self) -> &mut S

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Acquires a mutable reference to the underlying stream that this encoder is wrapping.

Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this encoder.

pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut S>

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Acquires a pinned mutable reference to the underlying stream that this encoder is wrapping.

Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this encoder.

pub fn into_inner(self) -> S

👎Deprecated since 0.3.8:

See async-compression::stream docs for migration

Consumes this encoder returning the underlying stream.

Note that this may discard internal state of this encoder, so care should be taken to avoid losing resources when this is called.