pub struct XzDecoder<S> { /* private fields */ }See async-compression::stream docs for migration
stream and xz only.Expand description
A xz decoder, or decompressor.
This structure implements a Stream interface and will read
compressed data from an underlying stream and emit a stream of uncompressed data.
Implementations
Sourceimpl<S: Stream<Item = Result<Bytes>>> XzDecoder<S>
impl<S: Stream<Item = Result<Bytes>>> XzDecoder<S>
Sourcepub fn new(stream: S) -> Self
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn new(stream: S) -> Self
See async-compression::stream docs for migration
Creates a new decoder which will read compressed data from the given stream and emit an uncompressed stream.
Sourcepub fn multiple_members(&mut self, enabled: bool)
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn multiple_members(&mut self, enabled: bool)
See async-compression::stream docs for migration
Configure multi-member/frame decoding, if enabled this will reset the decoder state when reaching the end of a compressed member/frame and expect either the end of the wrapped stream or another compressed member/frame to follow.
Sourcepub fn get_ref(&self) -> &S
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn get_ref(&self) -> &S
See async-compression::stream docs for migration
Acquires a reference to the underlying stream that this decoder is wrapping.
Sourcepub fn get_mut(&mut self) -> &mut S
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn get_mut(&mut self) -> &mut S
See async-compression::stream docs for migration
Acquires a mutable reference to the underlying stream that this decoder is wrapping.
Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this decoder.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut S>
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut S>
See async-compression::stream docs for migration
Acquires a pinned mutable reference to the underlying stream that this decoder is wrapping.
Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this decoder.
Sourcepub fn into_inner(self) -> S
👎Deprecated since 0.3.8: See async-compression::stream docs for migration
pub fn into_inner(self) -> S
See async-compression::stream docs for migration
Consumes this decoder returning the underlying stream.
Note that this may discard internal state of this decoder, so care should be taken to avoid losing resources when this is called.