pub struct GzipEncoder<R> { /* private fields */ }gzip only.Expand description
A gzip encoder, or compressor.
This structure implements an AsyncRead interface and will
read uncompressed data from an underlying stream and emit a stream of compressed data.
Implementations
Sourceimpl<R: AsyncBufRead> GzipEncoder<R>
impl<R: AsyncBufRead> GzipEncoder<R>
Sourcepub fn new(inner: R) -> Self
Available on crate feature tokio only.
pub fn new(inner: R) -> Self
tokio only.Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.
Sourcepub fn with_quality(inner: R, level: Level) -> Self
Available on crate feature tokio only.
pub fn with_quality(inner: R, level: Level) -> Self
tokio only.Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.
Sourcepub fn get_ref(&self) -> &R
Available on crate feature tokio only.
pub fn get_ref(&self) -> &R
tokio only.Acquires a reference to the underlying reader that this encoder is wrapping.
Sourcepub fn get_mut(&mut self) -> &mut R
Available on crate feature tokio only.
pub fn get_mut(&mut self) -> &mut R
tokio only.Acquires a mutable reference to the underlying reader that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>
Available on crate feature tokio only.
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>
tokio only.Acquires a pinned mutable reference to the underlying reader that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.
Sourcepub fn into_inner(self) -> R
Available on crate feature tokio only.
pub fn into_inner(self) -> R
tokio only.Consumes this encoder returning the underlying reader.
Note that this may discard internal state of this encoder, so care should be taken to avoid losing resources when this is called.