pub struct ZstdDecoder<W> { /* private fields */ }zstd only.Expand description
A zstd decoder, or decompressor.
This structure implements an AsyncWrite interface and will
take in compressed data and write it uncompressed to an underlying stream.
Implementations
Sourceimpl<W: AsyncWrite> ZstdDecoder<W>
impl<W: AsyncWrite> ZstdDecoder<W>
Sourcepub fn new(read: W) -> ZstdDecoder<W>
Available on crate feature tokio only.
pub fn new(read: W) -> ZstdDecoder<W>
tokio only.Creates a new decoder which will take in compressed data and write it uncompressedd to the given stream.
Sourcepub fn get_ref(&self) -> &W
Available on crate feature tokio only.
pub fn get_ref(&self) -> &W
tokio only.Acquires a reference to the underlying reader that this decoder is wrapping.
Sourcepub fn get_mut(&mut self) -> &mut W
Available on crate feature tokio only.
pub fn get_mut(&mut self) -> &mut W
tokio only.Acquires a mutable reference to the underlying reader that this decoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>
Available on crate feature tokio only.
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>
tokio only.Acquires a pinned mutable reference to the underlying reader that this decoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.
Sourcepub fn into_inner(self) -> W
Available on crate feature tokio only.
pub fn into_inner(self) -> W
tokio only.Consumes this decoder returning the underlying reader.
Note that this may discard internal state of this decoder, so care should be taken to avoid losing resources when this is called.