pub struct DeflateEncoder<R> { /* private fields */ }deflate only.Expand description
A deflate encoder, or compressor.
This structure implements an AsyncRead interface and will
read uncompressed data from an underlying stream and emit a stream of compressed data.
Implementations
Sourceimpl<R: AsyncBufRead> DeflateEncoder<R>
impl<R: AsyncBufRead> DeflateEncoder<R>
Sourcepub fn new(inner: R) -> Self
Available on crate feature tokio-02 only.
pub fn new(inner: R) -> Self
tokio-02 only.Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.
Sourcepub fn with_quality(inner: R, level: Level) -> Self
Available on crate feature tokio-02 only.
pub fn with_quality(inner: R, level: Level) -> Self
tokio-02 only.Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.
Sourcepub fn get_ref(&self) -> &R
Available on crate feature tokio-02 only.
pub fn get_ref(&self) -> &R
tokio-02 only.Acquires a reference to the underlying reader that this encoder is wrapping.
Sourcepub fn get_mut(&mut self) -> &mut R
Available on crate feature tokio-02 only.
pub fn get_mut(&mut self) -> &mut R
tokio-02 only.Acquires a mutable reference to the underlying reader that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>
Available on crate feature tokio-02 only.
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>
tokio-02 only.Acquires a pinned mutable reference to the underlying reader that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.
Sourcepub fn into_inner(self) -> R
Available on crate feature tokio-02 only.
pub fn into_inner(self) -> R
tokio-02 only.Consumes this encoder returning the underlying reader.
Note that this may discard internal state of this encoder, so care should be taken to avoid losing resources when this is called.