ZlibDecoder

pub struct ZlibDecoder<R> { /* private fields */ }
Available on crate feature zlib only.
A zlib decoder, or decompressor.

This structure implements an AsyncRead interface and will read compressed data from an underlying stream and emit a stream of uncompressed data.

Implementations

Source

impl<R: AsyncBufRead> ZlibDecoder<R>

pub fn new(read: R) -> ZlibDecoder<R>

Available on crate feature tokio-02 only.

Creates a new decoder which will read compressed data from the given stream and emit a uncompressed stream.

pub fn multiple_members(&mut self, enabled: bool)

Available on crate feature tokio-02 only.

Configure multi-member/frame decoding, if enabled this will reset the decoder state when reaching the end of a compressed member/frame and expect either EOF or another compressed member/frame to follow it in the stream.

pub fn get_ref(&self) -> &R

Available on crate feature tokio-02 only.

Acquires a reference to the underlying reader that this decoder is wrapping.

pub fn get_mut(&mut self) -> &mut R

Available on crate feature tokio-02 only.

Acquires a mutable reference to the underlying reader that this decoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.

pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>

Available on crate feature tokio-02 only.

Acquires a pinned mutable reference to the underlying reader that this decoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.

pub fn into_inner(self) -> R

Available on crate feature tokio-02 only.

Consumes this decoder returning the underlying reader.

Note that this may discard internal state of this decoder, so care should be taken to avoid losing resources when this is called.