ZlibEncoder

pub struct ZlibEncoder<R> { /* private fields */ }
Available on crate feature zlib only.
A zlib encoder, or compressor.

This structure implements an AsyncRead interface and will read uncompressed data from an underlying stream and emit a stream of compressed data.

Implementations

Source

impl<R: AsyncBufRead> ZlibEncoder<R>

pub fn new(inner: R) -> Self

Available on crate feature tokio-02 only.

Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.

pub fn with_quality(inner: R, level: Level) -> Self

Available on crate feature tokio-02 only.

Creates a new encoder which will read uncompressed data from the given stream and emit a compressed stream.

pub fn get_ref(&self) -> &R

Available on crate feature tokio-02 only.

Acquires a reference to the underlying reader that this encoder is wrapping.

pub fn get_mut(&mut self) -> &mut R

Available on crate feature tokio-02 only.

Acquires a mutable reference to the underlying reader that this encoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.

pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut R>

Available on crate feature tokio-02 only.

Acquires a pinned mutable reference to the underlying reader that this encoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this encoder.

pub fn into_inner(self) -> R

Available on crate feature tokio-02 only.

Consumes this encoder returning the underlying reader.

Note that this may discard internal state of this encoder, so care should be taken to avoid losing resources when this is called.