DeflateDecoder

Struct DeflateDecoder 

pub struct DeflateDecoder<W> { /* private fields */ }
Available on crate feature deflate only.
A deflate decoder, or decompressor.

This structure implements an AsyncWrite interface and will take in compressed data and write it uncompressed to an underlying stream.

Implementations

Source

impl<W: AsyncWrite> DeflateDecoder<W>

pub fn new(read: W) -> DeflateDecoder<W>

Available on crate feature tokio-02 only.

Creates a new decoder which will take in compressed data and write it uncompressedd to the given stream.

pub fn get_ref(&self) -> &W

Available on crate feature tokio-02 only.

Acquires a reference to the underlying reader that this decoder is wrapping.

pub fn get_mut(&mut self) -> &mut W

Available on crate feature tokio-02 only.

Acquires a mutable reference to the underlying reader that this decoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.

pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>

Available on crate feature tokio-02 only.

Acquires a pinned mutable reference to the underlying reader that this decoder is wrapping.

Note that care must be taken to avoid tampering with the state of the reader which may otherwise confuse this decoder.

pub fn into_inner(self) -> W

Available on crate feature tokio-02 only.

Consumes this decoder returning the underlying reader.

Note that this may discard internal state of this decoder, so care should be taken to avoid losing resources when this is called.