pub struct XzEncoder<W> { /* private fields */ }xz only.Expand description
A xz encoder, or compressor.
This structure implements an AsyncWrite interface and will
take in uncompressed data and write it compressed to an underlying stream.
Implementations
Sourceimpl<W: AsyncWrite> XzEncoder<W>
impl<W: AsyncWrite> XzEncoder<W>
Sourcepub fn new(inner: W) -> Self
Available on crate feature futures-io only.
pub fn new(inner: W) -> Self
futures-io only.Creates a new encoder which will take in uncompressed data and write it compressed to the given stream.
Sourcepub fn with_quality(inner: W, level: Level) -> Self
Available on crate feature futures-io only.
pub fn with_quality(inner: W, level: Level) -> Self
futures-io only.Creates a new encoder which will take in uncompressed data and write it compressed to the given stream.
Sourcepub fn get_ref(&self) -> &W
Available on crate feature futures-io only.
pub fn get_ref(&self) -> &W
futures-io only.Acquires a reference to the underlying writer that this encoder is wrapping.
Sourcepub fn get_mut(&mut self) -> &mut W
Available on crate feature futures-io only.
pub fn get_mut(&mut self) -> &mut W
futures-io only.Acquires a mutable reference to the underlying writer that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the writer which may otherwise confuse this encoder.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>
Available on crate feature futures-io only.
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut W>
futures-io only.Acquires a pinned mutable reference to the underlying writer that this encoder is wrapping.
Note that care must be taken to avoid tampering with the state of the writer which may otherwise confuse this encoder.
Sourcepub fn into_inner(self) -> W
Available on crate feature futures-io only.
pub fn into_inner(self) -> W
futures-io only.Consumes this encoder returning the underlying writer.
Note that this may discard internal state of this encoder, so care should be taken to avoid losing resources when this is called.